==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skrooge_scheduled/skgscheduledplugin.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSCHEDULEDPLUGIN_H
#define SKGSCHEDULEDPLUGIN_H
/** @file
 * A skrooge plugin to manage scheduled operations.
*
* @author Stephane MANKOWSKI
 */
#include "skginterfaceplugin.h"
#include "ui_skgscheduledpluginwidget_pref.h"

#include <QObject>
#include <QVariantList>
#include <kgenericfactory.h>

class SKGMainPanel;
class KAction;

/**
 * A skrooge plugin to manage scheduled operations
 */
class SKGScheduledPlugin : public SKGInterfacePlugin
{
        Q_OBJECT
        Q_INTERFACES(SKGInterfacePlugin);

public:
        /**
         * Default Constructor
         */
        SKGScheduledPlugin(QObject* iParent, const QVariantList& iArg);

        /**
         * Default Destructor
         */
        virtual ~SKGScheduledPlugin();

        /**
         * Called to initialise the plugin
         * @param iDocument the SKGDocumentBank main document
         * @param iArgument the arguments
         */
        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);

        /**
         * Must be modified to close properly the plugin.
         */
        virtual void close();

        /**
         * The number of dashboard widgets of the plugin.
         * @return The number of dashboard widgets of the plugin
         */
        virtual int getNbDashboardWidgets();

        /**
         * Get a dashboard widget title of the plugin.
         * @param iIndex the index of the widget
         * @return The title
         */
        virtual QString getDashboardWidgetTitle(int iIndex);

        /**
         * Get a dashboard widget of the plugin.
         * @param iIndex the index of the widget
         * @return The dashboard widget of the plugin
         */
        virtual SKGWidget* getDashboardWidget(int iIndex);

        /**
         * Must be modified to refresh widgets after a modification.
         */
        virtual void refresh();

        /**
        * The preference widget of the plugin.
        * @return The preference widget of the plugin
         */
        virtual QWidget* getPreferenceWidget();

        /**
         * The preference skeleton of the plugin.
         * @return The preference skeleton of the plugin
         */
        virtual KConfigSkeleton* getPreferenceSkeleton();

        /**
         * The context widget of the plugin.
         * @return The context widget of the plugin
         */
        virtual SKGTabWidget* getWidget();

        /**
         * The title of the plugin.
         * @return The title of the plugin
         */
        virtual QString title() const;

        /**
         * The icon of the plugin.
         * @return The icon of the plugin
         */
        virtual QString icon() const;

        /**
         * The statusTip of the plugin.
         * @return The toolTip of the plugin
         */
        virtual QString statusTip () const;

        /**
         * The toolTip of the plugin.
         * @return The toolTip of the plugin
         */
        virtual QString toolTip () const;

        /**
         * The tips list of the plugin.
         * @return The tips list of the plugin
         */
        virtual QStringList tips() const;

        /**
         * Must be implemented to set the position of the plugin.
         * @return integer value between 0 and 999 (default = 999)
         */
        virtual int getOrder() const;

        /**
         * Must be implemented to know if a plugin must be display in context chooser.
         * @return true of false (default = false)
         */
        virtual bool isInContext() const;

        /**
         * Must be implemented to know if this plugin is enabled
         * @return true of false (default = true)
         */
        virtual bool isEnabled() const;

private slots:
        void actionScheduleOperation();

private:
        Q_DISABLE_COPY(SKGScheduledPlugin);


        SKGDocument* currentBankDocument;
        QString docUniqueIdentifier;

        KAction* scheduleOperationAction;

        Ui::skgscheduledplugin_pref ui;
};

#endif // SKGSCHEDULEDPLUGIN_H

==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/skrooge_scheduled/skgscheduledplugin.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSCHEDULEDPLUGIN_H
#define SKGSCHEDULEDPLUGIN_H
/** @file
 * A skrooge plugin to manage scheduled operations.
*
* @author Stephane MANKOWSKI
 */
#include "skginterfaceplugin.h"
#include "ui_skgscheduledpluginwidget_pref.h"

#include <QObject>
#include <QVariantList>
#include <kgenericfactory.h>

class SKGMainPanel;
class KAction;

/**
 * A skrooge plugin to manage scheduled operations
 */
class SKGScheduledPlugin : public SKGInterfacePlugin
{
        Q_OBJECT
        Q_INTERFACES(SKGInterfacePlugin);

public:
        /**
         * Default Constructor
         */
        SKGScheduledPlugin(QObject* iParent, const QVariantList& iArg);

        /**
         * Default Destructor
         */
        virtual ~SKGScheduledPlugin();

        /**
         * Called to initialise the plugin
         * @param iDocument the SKGDocumentBank main document
         * @param iArgument the arguments
         */
        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);

        /**
         * Must be modified to close properly the plugin.
         */
        virtual void close();

        /**
         * The number of dashboard widgets of the plugin.
         * @return The number of dashboard widgets of the plugin
         */
        virtual int getNbDashboardWidgets();

        /**
         * Get a dashboard widget title of the plugin.
         * @param iIndex the index of the widget
         * @return The title
         */
        virtual QString getDashboardWidgetTitle(int iIndex);

        /**
         * Get a dashboard widget of the plugin.
         * @param iIndex the index of the widget
         * @return The dashboard widget of the plugin
         */
        virtual SKGWidget* getDashboardWidget(int iIndex);

        /**
         * Must be modified to refresh widgets after a modification.
         */
        virtual void refresh();

        /**
        * The preference widget of the plugin.
        * @return The preference widget of the plugin
         */
        virtual QWidget* getPreferenceWidget();

        /**
         * The preference skeleton of the plugin.
         * @return The preference skeleton of the plugin
         */
        virtual KConfigSkeleton* getPreferenceSkeleton();

        /**
         * This function is called when preferences have been modified. Must be used to save some parameters into the document.
         * A transaction is already opened
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError savePreferences() const;

        /**
         * The context widget of the plugin.
         * @return The context widget of the plugin
         */
        virtual SKGTabPage* getWidget();

        /**
         * The title of the plugin.
         * @return The title of the plugin
         */
        virtual QString title() const;

        /**
         * The icon of the plugin.
         * @return The icon of the plugin
         */
        virtual QString icon() const;

        /**
         * The toolTip of the plugin.
         * @return The toolTip of the plugin
         */
        virtual QString toolTip () const;

        /**
         * The tips list of the plugin.
         * @return The tips list of the plugin
         */
        virtual QStringList tips() const;

        /**
         * Must be implemented to set the position of the plugin.
         * @return integer value between 0 and 999 (default = 999)
         */
        virtual int getOrder() const;

        /**
         * Must be implemented to know if a plugin must be display in context chooser.
         * @return true of false (default = false)
         */
        virtual bool isInContext() const;

        /**
         * Must be implemented to know if this plugin is enabled
         * @return true of false (default = true)
         */
        virtual bool isEnabled() const;

private slots:
        void actionScheduleOperation();

private:
        Q_DISABLE_COPY(SKGScheduledPlugin);


        SKGDocument* currentBankDocument;
        QString docUniqueIdentifier;

        KAction* scheduleOperationAction;

        Ui::skgscheduledplugin_pref ui;
};

#endif // SKGSCHEDULEDPLUGIN_H
